
dialogId("odp-v-kachna", "font_big", "Doesn’t this duck look suspicious to you?")
dialogStr("Non ti sembra sospetta questa papera?")

dialogId("odp-m-zda0", "font_small", "I think it looks dumb.")
dialogStr("A me sembra muta.")

dialogId("odp-m-zda1", "font_small", "I think it looks inflatable.")
dialogStr("A me sembra gonfiabile.")

dialogId("odp-v-snehulak", "font_big", "Can you see that snowman?")
dialogStr("Riesci a vedere quell'uomo di neve?")

dialogId("odp-m-blaznis", "font_small", "What do you mean? Snowmen belong to the Mess Hall.")
dialogStr("Che dici? I pupazzi di neve stanno in mensa.")

dialogId("odp-m-kohout", "font_small", "Try to open that tap!")
dialogStr("Prova ad aprire quel tappo!")

dialogId("odp-v-vtip", "font_big", "Now, this was a joke. Heh, heh.")
dialogStr("Era uno scherzo, eh eh.")

dialogId("odp-m-predmet", "font_small", "And there isn't even a funny animated object here.")
dialogStr("E non c'è neanche un bell'oggetto animato qui.")

dialogId("odp-v-pozadi", "font_big", "But a beautifully wavy background.")
dialogStr("Ma un bellissimo sfondo andeggiante.")

dialogId("odp-v-pohni", "font_big", "Move on, so that we can get going.")
dialogStr("Muoviti, così possiamo andarcene.")

dialogId("odp-v-coja", "font_big", "And what about me?")
dialogStr("E io?")

dialogId("odp-v-nestacim", "font_big", "Am I not enough for you now, or what?")
dialogStr("Io non ti basto più, o cosa?")

